@@ -39,6 +39,7 @@ class TitleBar;
 
 class KHelpMenu;
 class KActionCollection;
+class KStatusNotifierItem;
 
 #if HAVE_KWAYLAND
 namespace KWayland {
@@ -95,6 +96,7 @@ class MainWindow : public KMainWindow
         void changeEvent(QEvent* event) override;
         void closeEvent(QCloseEvent *event) override;
         bool event(QEvent* event) override;
+        bool focusNextPrevChild(bool) override;
 
         virtual bool queryClose() override;
 
@@ -141,6 +143,7 @@ class MainWindow : public KMainWindow
         void configureKeys();
         void configureNotifications();
         void configureApp();
+        void updateTrayTooltip();
 
         void showFirstRunDialog();
         void firstRunDialogFinished();
@@ -172,9 +175,12 @@ class MainWindow : public KMainWindow
         void updateMask();
 
         int getScreen();
+        QRect getScreenGeometry();
         QRect getDesktopGeometry();
 
-        void showStartupPopup();
+        // get a better value from plasmashell through dbus in wayland case
+        QRect m_availableScreenRect;
+        void _toggleWindowState();
 
         void updateUseTranslucency();
         bool m_useTranslucency;
@@ -195,6 +201,7 @@ class MainWindow : public KMainWindow
         QMenu* m_windowHeightMenu;
 
         FirstRunDialog* m_firstRunDialog;
+        KStatusNotifierItem *m_notifierItem;
 
         QTimer m_animationTimer;
         QTimer m_mousePoller;
