@@ -16,7 +16,7 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program. If not, see http://www.gnu.org/licenses/.
+  along with this program. If not, see https://www.gnu.org/licenses/.
 */
 
 
@@ -41,7 +41,7 @@ class Session : public QObject
         enum SessionType { Single, TwoHorizontal, TwoVertical, Quad };
         enum GrowthDirection { Up, Right, Down, Left };
 
-        explicit Session(SessionType type = Single, QWidget* parent = 0);
+        explicit Session(const QString& workingDir, SessionType type = Single, QWidget* parent = 0);
          ~Session();
 
         int id() { return m_sessionId; }
@@ -79,7 +79,7 @@ class Session : public QObject
         bool hasTerminalsWithMonitorSilenceDisabled();
 
 
-    public slots:
+    public Q_SLOTS:
         void closeTerminal(int terminalId = -1);
 
         void focusNextTerminal();
@@ -98,7 +98,7 @@ class Session : public QObject
         void reconnectMonitorActivitySignals();
 
 
-    signals:
+    Q_SIGNALS:
         void titleChanged(const QString& title);
         void titleChanged(int sessionId, const QString& title);
         void terminalManuallyActivated(Terminal* terminal);
@@ -108,7 +108,7 @@ class Session : public QObject
         void destroyed(int sessionId);
 
 
-    private slots:
+    private Q_SLOTS:
         void setActiveTerminal(int terminalId);
         void setTitle(int terminalId, const QString& title);
 
@@ -120,9 +120,10 @@ class Session : public QObject
     private:
         void setupSession(SessionType type);
 
-        Terminal* addTerminal(QWidget* parent);
+        Terminal* addTerminal(QWidget* parent, QString workingDir = QString());
         int split(Terminal* terminal, Qt::Orientation orientation);
 
+        QString m_workingDir;
         static int m_availableSessionId;
         int m_sessionId;
 
