@@ -52,7 +52,7 @@ SessionStack::~SessionStack()
 int SessionStack::addSessionImpl(Session::SessionType type)
 {
     Session* currentSession  = m_sessions.value(activeSessionId());
-    Terminal* currentTerminal = currentSession ? currentSession->getTerminal(currentSession->activeTerminalId()) : NULL;
+    Terminal* currentTerminal = currentSession ? currentSession->getTerminal(currentSession->activeTerminalId()) : nullptr;
     QString workingDir = currentTerminal ? currentTerminal->currentWorkingDirectory() : QString();
 
     Session* session = new Session(workingDir, type, this);
@@ -604,7 +604,7 @@ bool SessionStack::requiresVisualEventOverlay()
 
 void SessionStack::handleTerminalHighlightRequest(int terminalId)
 {
-    Terminal* terminal = 0;
+    Terminal* terminal = nullptr;
 
     QHashIterator<int, Session*> it(m_sessions);
 
@@ -673,3 +673,30 @@ bool SessionStack::queryClose(int sessionId, QueryCloseType type)
 
     return true;
 }
+
+
+QList<KActionCollection*> SessionStack::getPartActionCollections()
+{
+    QList<KActionCollection*> actionCollections;
+
+    const auto sessions = m_sessions.values();
+    for (auto* session : sessions) {
+
+        const auto terminalIds = session->terminalIdList().split(QStringLiteral(","));
+
+        for (const auto& terminalID : terminalIds) {
+
+            auto *terminal = session->getTerminal(terminalID.toInt());
+            if (terminal) {
+                auto* collection = terminal->actionCollection();
+                if (collection) {
+                    actionCollections.append(collection);
+                }
+            }
+
+        }
+
+    }
+
+    return actionCollections;
+}
